@@ -33,6 +33,14 @@ class u32(int):
     pass
 
 
+class u64(int):
+    pass
+
+
+class u128(int):
+    pass
+
+
 def get_origin(tp):
     """
     Returns the containing type
@@ -107,10 +115,22 @@ def deserialize_u32(value_type: type, value: bytes) -> int:
     return int.from_bytes(value, "little")
 
 
+def deserialize_u64(value_type: type, value: bytes) -> int:
+    return int.from_bytes(value, "little")
+
+
+def deserialize_u128(value_type: type, value: bytes) -> int:
+    return int.from_bytes(value, "little")
+
+
 def deserialize_str(value_type: type, value: bytes) -> str:
     return value.decode("utf-8")
 
 
+def deserialize_bytes(value_type: type, value: bytes) -> bytes:
+    return value
+
+
 def deserialize_int_enum(value_type: type, value: bytes) -> enum.IntEnum:
     int_value = deserialize_u8(value_type, value)
     return value_type(int_value)
@@ -142,10 +162,22 @@ def serialize_u32(value_type: type, value: int) -> bytes:
     return struct.pack("I", value)
 
 
+def serialize_u64(value_type: type, value: int) -> bytes:
+    return struct.pack("Q", value)
+
+
+def serialize_u128(value_type: type, value: int) -> bytes:
+    return value.to_bytes(length=16, byteorder="little")
+
+
 def serialize_str(value_type: type, value: str) -> bytes:
     return value.encode("utf-8")
 
 
+def serialize_bytes(value_type: type, value: bytes) -> bytes:
+    return value
+
+
 def serialize_int_enum(value_type: type, value: enum.IntEnum) -> bytes:
     return serialize_u8(value_type, int(value))
 
@@ -215,6 +247,8 @@ class TLVStruct:
         result = bytearray()
 
         for struct_field in fields(self):
+            if not struct_field.init:
+                continue
             value = getattr(self, struct_field.name)
 
             if value is None:
@@ -241,7 +275,9 @@ class TLVStruct:
 
         # FIXME: Would by good if we could cache this per cls
         # And not rebuild it every time decode() is called
-        tlv_types = {field.metadata["tlv_type"]: field for field in fields(cls)}
+        tlv_types = {
+            field.metadata["tlv_type"]: field for field in fields(cls) if field.init
+        }
 
         for offset, type, length, value in tlv_iterator(encoded_struct):
             if type not in tlv_types:
@@ -259,18 +295,24 @@ DESERIALIZERS: dict[type, DeserializerCallback] = {
     u8: deserialize_u8,
     u16: deserialize_u16,
     u32: deserialize_u32,
+    u64: deserialize_u64,
+    u128: deserialize_u128,
     str: deserialize_str,
     enum.IntEnum: deserialize_int_enum,
     TLVStruct: deserialize_tlv_struct,
     abc.Sequence: deserialize_typing_sequence,
+    bytes: deserialize_bytes,
 }
 
 SERIALIZERS: dict[type, SerializerCallback] = {
     u8: serialize_u8,
     u16: serialize_u16,
     u32: serialize_u32,
+    u64: serialize_u64,
+    u128: serialize_u128,
     str: serialize_str,
     enum.IntEnum: serialize_int_enum,
     TLVStruct: serialize_tlv_struct,
     abc.Sequence: serialize_typing_sequence,
+    bytes: serialize_bytes,
 }
